@@ -1,76 +1,49 @@
-#! /usr/bin/env python
-# __init__.py (libtovid)
-
 """Provides a Python interface to the functionality of tovid.
 """
 
-## \mainpage How to use libtovid
-# 
-# \section intro Introduction
-# 
-# libtovid is a Python module oriented towards creating video discs. It has
-# the following submodules:
-#
-# - transcode
-#   - rip.py
-#   - encode.py
-#   - subtitles.py
-# - layout
-# - render
-#   - drawing.py
-#   - animation.py
-#   - layer.py
-#   - effect.py
-#   - flipbook.py
-# - Layers in layer.py, to put something in your canvas
-# - Effects in effect.py, for several effects, which you can extend
-# - Flipbook for animation
-# - Drawing module in drawing.py for drawing primitives
-# - Tween and Keyframe in animation.py, for key-framing
-#
-#
-# <i>You'll find this page in %libtovid/__init__.py</i>
-
-
-__all__ = [\
+__all__ = [
     # Subdirectories
-    'author',
+    'backend',
     'gui',
+    'guis',
     'metagui',
     'render',
     'template',
     'test',
-    'transcode',
+    'util',
     # .py files
+    'author',
     'cli',
     'deps',
-    'layout'
-    'media',
+    'encode',
     'odict',
     'opts',
-    'output',
-    'playtime',
-    'spumux',
+    'rip',
     'standard',
     'stats',
     'utils',
-    'xml']
+    'xml',
+]
 
 import os
-import sys
-from ConfigParser import ConfigParser
 
+# Python < 3.x
+try:
+    from ConfigParser import ConfigParser
+# Python 3.x
+except ImportError:
+    from configparser import ConfigParser
 
 # Configuration file reader/writer
 class Config (ConfigParser):
-    """Interface for reading/writing tovid configuration file. Just a wrapper
+    """Interface for reading/writing tovid configuration files. Just a wrapper
     around the standard library ConfigParser. Example usage:
-    
+
         config = libtovid.Config()
         config.get('DEFAULT', 'work_dir')
         config.set('tovid', 'method', 'ffmpeg')
         config.save()
-        
+
     See the ConfigParser documentation for details.
     """
     # Dictionary of suite-wide configuration defaults
@@ -92,8 +65,11 @@ class Config (ConfigParser):
         outfile.close()
 
 
+
 # Logging class
 class Log:
+    """Logging class, with five severity levels.
+    """
     # Increasing levels of severity
     _levels = {
         'debug': 1,
@@ -101,15 +77,15 @@ class Log:
         'warning': 3,
         'error': 4,
         'critical': 5}
-    
+
     def __init__(self, level='info'):
         """Create a logger with the given severity level."""
         self.level = level
-    
+
     def message(self, level, text):
         """Print a message if it's at the current severity level or higher."""
         if Log._levels[level] >= Log._levels[self.level]:
-            print text
+            print(text)
 
     def debug(self, text):
         """Log a debugging message."""
@@ -131,5 +107,7 @@ class Log:
         """Log a critical error message."""
         self.message('critical', "CRITICAL: " + text)
 
+
+
 # Global logger
 log = Log()
