@@ -1,25 +1,25 @@
-#! /usr/bin/env python
 # opts.py
 
 # WARNING: This module is a hack in progress
 
-__all__ = [\
+__all__ = [
     'Option',
     'Usage',
     'parse',
-    'validate']
+    'validate',
+]
 
-### --------------------------------------------------------------------
+import sys
 import textwrap
 from libtovid.odict import Odict
-from libtovid.utils import trim
+from libtovid.util import trim
 
 class Option (object):
     """A command-line-style option, expected argument formatting, default value,
     and notes on usage and purpose.
-    
-    For example:
-        
+
+    For example::
+
         debug_opt = Option(
             'debug',
             'none|some|all',
@@ -29,19 +29,23 @@ class Option (object):
 
     This defines a 'debug' option, along with a human-readable string showing
     expected argument formatting, a default value, and a string documenting the
-    option's purpose and/or usage information."""
-
+    option's purpose and/or usage information.
+    """
     def __init__(self, name, argformat='', default=None,
                  doc='Undocumented option', alias=None,
                  required=False):
         """Create a new option definition with the given attributes.
-        
-            name:      Option name
-            argformat: String describing format of expected arguments
-                       (see is_valid() for examples)
-            default:   Default value, if any
-            doc:       Manual-page-style documentation of the option
-            alias:     An ('option', 'value') equivalent for this option.
+
+            name
+                Option name
+            argformat
+                String describing format of expected arguments
+            default
+                Default value, if any
+            doc
+                Manual-page-style documentation of the option
+            alias
+                An ('option', 'value') equivalent for this option
 
         """
         self.name = name
@@ -56,24 +60,28 @@ class Option (object):
         if self.alias:
             self.doc = 'Same as -%s %s.' % alias
 
+
     def num_args(self):
-        """Return the number of arguments expected by this option, or -1 if
-        unlimited."""
+        """Return the number of arguments expected by this option,
+        or -1 if unlimited.
+        """
         # Flag alias for another option
         if self.alias:
             return 0
+        # Boolean: no argument
         elif isinstance(self.default, bool):
-            # Boolean: no argument
             return 0
+        # List: unlimited arguments
         elif isinstance(self.default, list):
-            # List: unlimited arguments
             return -1
+        # Unary: one argument
         else:
-            # Unary: one argument
             return 1
-    
+
+
     def __str__(self):
-        """Return a string containing "usage notes" for this option."""
+        """Return a string containing "usage notes" for this option.
+        """
         if self.alias:
             usage = "-%s: Same as '-%s %s'\n" % \
                   (self.name, self.alias[0], self.alias[1])
@@ -87,60 +95,62 @@ class Option (object):
                 usage += '    ' + line + '\n'
         return usage
 
-### --------------------------------------------------------------------
-
 class Usage (object):
     """Command-line usage definition."""
     def __init__(self, usage_string='program [options]', *options):
         """Define usage of a command-line program.
-        
-            usage_string: Command-line syntax and required options
-            *options:     List of allowed Options
 
-        Examples:
+            usage_string
+                Command-line syntax and required options
+            options
+                List of allowed Options
+
+        Examples::
+
+            usage = Usage('pytovid [options] -in FILENAME -out NAME',
+                Option('in', 'FILENAME', None,
+                    "Input video file, in any format."),
+                Option('out', 'NAME', None,
+                    "Output prefix or name."),
+                Option('format', 'vcd|svcd|dvd|half-dvd|dvd-vcd', 'dvd',
+                    "Make video compliant with the specified format")
+            )
+            print(usage)
+            print(usage.options['format'])
 
-        usage = Usage('pytovid [options] -in FILENAME -out NAME',
-            Option('in', 'FILENAME', None,
-                "Input video file, in any format."),
-            Option('out', 'NAME', None,
-                "Output prefix or name."),
-            Option('format', 'vcd|svcd|dvd|half-dvd|dvd-vcd', 'dvd',
-                "Make video compliant with the specified format")
-        )
-        
-        print usage
-        print usage.options['format']
-        
         """
         self.usage_string = usage_string
         # Odict of options indexed by name
         names = [opt.name for opt in options]
         self.options = Odict(names, options)
 
+
     def __str__(self):
-        """Return string-formatted usage notes."""
+        """Return string-formatted usage notes.
+        """
         result = "Usage: %s\n" % self.usage_string
         result += "Allowed options:\n"
         option_list = ['-' + opt.name for opt in self.options.values()]
         result += ', '.join(option_list)
         return result
 
-### --------------------------------------------------------------------
+
+
 from copy import copy
 
 def parse(args):
     """Parse a list of arguments and return a dictionary of found options.
 
         args:    List of command-line arguments (such as from sys.argv)
-    
+
     The argument list is interpreted in this way:
-    
-        - If it begins with '-', it's an option
-        - Arguments that precede the first option are ignored
-        - Anything following an option is an argument to that option
-        - If there is no argument to an option, it's a flag (True if present)
-        - If there's one argument to an option, it's a single string value
-        - If there are multiple arguments to an option, it's a list of strings
+
+        * If it begins with '-', it's an option
+        * Arguments that precede the first option are ignored
+        * Anything following an option is an argument to that option
+        * If there is no argument to an option, it's a flag (True if present)
+        * If there's one argument to an option, it's a single string value
+        * If there are multiple arguments to an option, it's a list of strings
 
     """
     args = copy(args)
@@ -150,14 +160,14 @@ def parse(args):
         arg = args.pop(0)
         # New option
         if arg.startswith('-'):
-            # Assume it's a flag unless we see arguments later
             current = arg.lstrip('-')
+            # Treat it as a flag unless we see arguments later
             options[current] = True
-            
+
         # Argument to current option
         elif current:
             # Was a flag, now has a single value
-            if options[current] == True:
+            if options[current] is True:
                 options[current] = arg
             # Was a single value, now a list
             elif type(options[current]) != list:
@@ -168,17 +178,16 @@ def parse(args):
     return options
 
 
-### --------------------------------------------------------------------
 import re
 
 def validate(option, arg):
     """Check whether an argument is valid for a given option.
-    
+
         option: An Option to validate
         arg:    Candidate argument
 
     Expected/allowed values are inferred from the argformat string.
-    
+
     argformat patterns to consider:
         opta|optb|optc      # Either opta, optb, or optc
         [100-999]           # Any integer between 100 and 999
@@ -230,16 +239,16 @@ def validate(option, arg):
     return True
 
 
-import sys
+
 if __name__ == '__main__':
-    print "Option-parsing demo"
+    print("Option-parsing demo")
 
-    print "You passed the following arguments:"
-    print sys.argv[1:]
+    print("You passed the following arguments:")
+    print(sys.argv[1:])
 
-    print "Parsing..."
+    print("Parsing...")
     options = parse(sys.argv[1:])
 
-    print "Found the following options:"
-    print options
-    
+    print("Found the following options:")
+    print(options)
+
