@@ -1,6 +1,4 @@
-#! /usr/bin/env python
 # -=- encoding: latin-1 -=-
-# drawing.py
 
 # Run this script standalone for a demonstration:
 #    $ python libtovid/render/drawing.py
@@ -12,49 +10,53 @@
 """Interactive vector drawing and rendering interface.
 
 This module provides a class called Drawing, which provides a blank canvas
-that can be painted with drawing functions. To use it, simply provide a
-width and height, in arbitrary units:
+that can be painted with vector drawing functions, and later rendered to
+a raster image file (.png, .jpg etc.) at any desired resolution.
 
-    >>> drawing = Drawing(800, 600)   # width, height
+To create a new, blank Drawing::
 
-This does not imply the *pixel* resolution of your drawing. Remember, this
-is vector drawing, with (virtually) infinite precision; all you're describing
-here is the *shape* of the drawing--800 units by 600 units, which implies a
-4:3 aspect ratio. You could just as well do Drawing(4, 3) or Drawing(80, 60);
-the only thing that changes is the coordinate system you want to use for
-drawing operations.
+    >>> d = Drawing(800, 600)          # width, height
 
-Back on topic: you can now draw shapes on the drawing, fill and stroke them:
+Here, (800, 600) defines two things:
 
-    >>> drawing.circle(500, 300, 150)        # (x, y, radius)
-    >>> drawing.fill('blue', 0.8)            # color name with optional alpha
-    >>> drawing.stroke('rgb(0, 128, 255)')   # rgb values 0-255
+    - On-screen display size, in pixels (800px x 600px)
+    - Intended viewing aspect ratio (800:600 or 4:3)
 
-Then add more shapes:
+Note that you are still doing vector drawing, so whatever size you pick here
+has no bearing on your final target resolution--it's mostly intended for a
+convenient "preview" size while doing interactive drawing.
 
-    >>> drawing.rectangle(25, 25, 320, 240)  # x, y, width, height
-    >>> drawing.fill('rgb(40%, 80%, 10%)')   # rgb percentages
-    >>> drawing.stroke('#FF0080', 0.5)       # rgb hex notation with an alpha
+Back on topic: you can now add shapes to the drawing, fill and stroke them::
 
-To see what the drawing looks like so far, do:
+    >>> d.circle(500, 300, 150)        # (x, y, radius)
+    >>> d.fill('blue', 0.8)            # color name with optional alpha
+    >>> d.stroke('rgb(0, 128, 255)')   # rgb values 0-255
 
-    >>> display(drawing)                     # display at existing size
-    >>> display(drawing, 720, 480)           # display at different size
-    >>> display(drawing, fix_aspect=True)    # display in correct aspect ratio
+Then add more shapes::
 
-You may then decide to add more to the drawing:
+    >>> d.rectangle(25, 25, 320, 240)  # x, y, width, height
+    >>> d.fill('rgb(40%, 80%, 10%)')   # rgb percentages
+    >>> d.stroke('#FF0080', 0.5)       # rgb hex notation with an alpha
 
-    >>> drawing.set_source('white')
-    >>> drawing.text("Dennis", 50, 100)      # text, x, y
+To see what the drawing looks like so far, do::
 
-And preview again:
+    >>> display(d)                     # display at existing size
+    >>> display(d, 720, 480)           # display at different size
+    >>> display(d, fix_aspect=True)    # display in correct aspect ratio
 
-    >>> display(drawing)
+You may then decide to add more to the drawing::
 
-Once you finish your beautiful painting, save it as a nice high-res PNG!
+    >>> d.set_source('white')
+    >>> d.text("Dennis", 50, 100)      # text, x, y
+
+And preview again::
+
+    >>> display(d)
+
+Once you finish your beautiful painting, save it as a nice high-res PNG::
+
+    >>> save_png(d, "my.png", 1600, 1200)
 
-    >>> save_png(drawing, "my.png", 1600, 1200)
-    
 Cairo references:
 
     [1] http://www.cairographics.org
@@ -72,7 +74,8 @@ __all__ = [
     'save_png',
     'save_ps',
     'save_svg',
-    'write_ppm']
+    'write_ppm',
+]
 
 import os
 import sys
@@ -85,11 +88,7 @@ import Image      # for JPG export
 import ImageColor # for getrgb, getcolor
 import ImageFile  # for write_png()
 from libtovid import log
-from libtovid.utils import to_unicode
-
-### --------------------------------------------------------------------
-### Internal functions
-### --------------------------------------------------------------------
+from libtovid.util import to_unicode
 
 def get_surface(width, height, surface_type='image', filename=''):
     """Get a cairo surface at the given dimensions.
@@ -113,7 +112,6 @@ def get_surface(width, height, surface_type='image', filename=''):
 ### --------------------------------------------------------------------
 ### Classes
 ### --------------------------------------------------------------------
-
 class Step:
     """An atomic drawing procedure, consisting of a closed function that
     draws on a given cairo surface, and human-readable information about
@@ -126,34 +124,34 @@ class Step:
     def __str__(self):
         return "%s%s" % (self.name, self.args)
 
-# Drawing class notes:
-#
-# The Drawing class has a number of methods (circle, rectangle, fill, stroke
-# and many others) that need to operate on a Cairo surface. But we'd like to
-# delay execution of actually drawing on that surface--otherwise, we can't
+# Drawing class notes
+# 
+# The Drawing class has a number of methods (circle, rectangle, fill, stroke 
+# and many others) that need to operate on a Cairo surface. But we'd like to 
+# delay execution of actually drawing on that surface--otherwise, we can't 
 # easily render a given Drawing to a custom resolution.
-#
-# Closures save the day here--that is, functions without "free variables".
-# Anytime you "paint" on the Drawing, what's actually happening is a new
-# function is getting created, whose sole purpose in life is to carry out
-# that specific paint operation. These tiny, single-purpose functions are
-# then added to a list of steps (self.steps) that will actually be
-# executed at rendering-time (i.e., when you do display() or save_png).
-#
-# This not only lets us render a Drawing to different resolutions, but allows
+# 
+# Closures save the day here--that is, functions without "free variables". 
+# Anytime you "paint" on the Drawing, what's actually happening is a new 
+# function is getting created, whose sole purpose in life is to carry out that 
+# specific paint operation. These tiny, single-purpose functions are then 
+# added to a list of steps (self.steps) that will actually be executed at 
+# rendering-time (i.e., when you do display() or save_png).
+# 
+# This not only lets us render a Drawing to different resolutions, but allows 
 # the possibility of rendering to different Cairo surfaces.
 
 class Drawing:
 
     tk = None # tkinter widget to send redraws to
-    
+
     def __init__(self, width=800, height=600, autodraw=False):
         """Create a blank drawing at the given size.
-        
-            width, height: Dimensions of the drawable region,
-                           in arbitrary units
-            autodraw:      Redraw a preview image after each
-                           drawing operation
+
+            width, height
+                Dimensions of the drawable region, in arbitrary units
+            autodraw
+                Redraw a preview image after each drawing operation
         """
         self.size = (width, height)
         self.w = width
@@ -188,20 +186,16 @@ class Drawing:
         return result
 
 
-    ### -----------------------------------------------------------------
-    ### Drawing commands
-    ### -----------------------------------------------------------------
-
     def affine(self, rot_x, rot_y, scale_x, scale_y, translate_x, translate_y):
-        """Define a 3x3 transformation matrix:
-            
+        """Define a 3x3 transformation matrix::
+
             [ scale_x  rot_y    translate_x ]
             [ rot_x    scale_y  translate_y ]
             [ 0        0        1           ]
 
         This is scaling, rotation, and translation in a single matrix,
         so it's a compact way to represent any transformation.
-        
+
         See [http://www.w3.org/TR/SVG11/coords.html] for more on
         these matrices and how to use them.
         """
@@ -233,29 +227,30 @@ class Drawing:
 
     # TODO: Rewrite/cleanup bezier function
     def bezier(self, points, rel=False, close_path=False):
-        """Create a Bzier curve.
+        """Create a Bezier curve.
+
+        Points should look like::
 
-            points should look like:
-            
             points = [[(x0, y0), (x_ctl1, y_ctl1), (x_ctl2, y_ctl2)],
                       [(x0, y0), (x_ctl1, y_ctl1), (x_ctl2, y_ctl2)],
                       [(x0, y0), (x_ctl1, y_ctl1), (x_ctl2, y_ctl2)],
                       [(x0, y0)],
                       ]
-             
+
         where (x0, y0) are the point coordinates, and x_ctl* are the control
         points coordinates.
 
-            *ctl1 - control from last point
-            *ctl2 - control to next point
+            - ctl1 - control from last point
+            - ctl2 - control to next point
 
         The last line would specify that control points
         are at the same place (x0, y0), drawing straight lines.
 
-            rel -- when this is True, the x_ctl and y_ctl become relatives
-                   to the (x0, y0) points
-            close_path -- set this to True to call cr.close_path() before
-                          stroking.
+            rel
+                when this is True, the x_ctl and y_ctl become relatives
+                to the (x0, y0) points
+            close_path
+                set this to True to call cr.close_path() before stroking.
 
         """
         assert len(points) > 1, "You need at least two points"
@@ -270,7 +265,7 @@ class Drawing:
                        "to specify two-values tuples"
         # Map relative stuff to absolute, when rel=True
         if rel:
-            for x in range(0,len(points)):
+            for x in range(0, len(points)):
                 pt = points[x]
                 assert len(pt) == 3, "In relative mode, you must "\
                        "specify control points"
@@ -281,7 +276,7 @@ class Drawing:
                 npt.append([pt[0][0] + pt[1][0], pt[0][1] + pt[1][1]])
                 npt.append([pt[0][0] + pt[2][0], pt[0][1] + pt[2][1]])
                 points[x] = npt
-                    
+
         # Define the actual drawing function
         def _bezier(cr):
             # Move to the first x,y in the first point
@@ -303,8 +298,6 @@ class Drawing:
             cr.arc(center_x, center_y, radius, 0, 2*pi)
         self.doStep(_circle, center_x, center_y, radius)
 
-    # TODO: add clip stuff...
-
 
     def fill(self, source=None, opacity=None):
         """Fill the current (closed) path with an optionally given color.
@@ -324,12 +317,12 @@ class Drawing:
 
     def fill_rule(self, rule):
         """Set the fill rule to one of:
-        
+
             evenodd, winding (nonzero)
 
         This determines which parts of an overlapping path polygon will
         be filled with the fill() command.
-            
+
         http://www.w3.org/TR/SVG/painting.html#FillRuleProperty
         """
         tr = {'evenodd': cairo.FILL_RULE_EVEN_ODD,
@@ -337,18 +330,21 @@ class Drawing:
 
         # Test value
         tr[rule]
-        
+
         def _fill_rule(cr):
             cr.set_fill_rule(tr[rule])
         self.doStep(_fill_rule, rule)
 
 
     def font(self, name, slant='normal', weight='normal'):
-        """Set the current font, by name.
+        """Set the current font.
 
-        name -- name of the Font, or family (sans-serif, serif)
-        slant -- one of: italic, normal, oblique
-        weight -- one of: normal, bold
+            name
+                name of the Font, or family (sans-serif, serif)
+            slant
+                one of: italic, normal, oblique
+            weight
+                one of: normal, bold
         """
         sl = {'italic': cairo.FONT_SLANT_ITALIC,
               'normal': cairo.FONT_SLANT_NORMAL,
@@ -361,7 +357,8 @@ class Drawing:
 
 
     def font_size(self, pointsize):
-        """Set the current font size in points."""
+        """Set the current font size in points.
+        """
         def _font_size(cr):
             cr.set_font_size(pointsize)
         self.doStep(_font_size, pointsize)
@@ -391,12 +388,12 @@ class Drawing:
             cr.set_font_matrix(m)
         self.doStep(_font_rotate, degrees)
 
+
     def image_surface(self, x, y, width, height, surface, mask=None):
         """Draw a given cairo.ImageSurface centered at (x, y), at the given
         width and height.
 
         If you specify mask, it must be a cairo ImageSurface.
-        
         """
         # Calculate centering and scaling
         add_x, add_y = (0, 0)
@@ -408,7 +405,7 @@ class Drawing:
         else:
             scale = dw
             add_y = (height - dw * float(surface.get_height())) / 2
-        
+
         # Save context and get the surface to right dimensions
         self.save()
         self.translate(x + add_x, y + add_y)
@@ -427,17 +424,18 @@ class Drawing:
             self.doStep(_image_surface, x, y, width, height, surface, mask)
 
         self.restore()
-    
+
 
     def image(self, x, y, width, height, source):
         """Draw an image centered at (x, y), scaled to the given width and
         height. Return the corresponding cairo.ImageSurface object.
 
-        source -- a .png filename (quicker and alpha present),
-                  a cairo.ImageSurface object, which is even better,
-                  a file object
-                  a filename - any file supported by python-imaging,
-                               a.k.a PIL [1]
+            source
+                - a .png filename (quicker and alpha present),
+                - a cairo.ImageSurface object, which is even better,
+                - a file object
+                - a filename - any file supported by python-imaging,
+                  a.k.a PIL [1]
 
         Ref:
           [1] http://www.pythonware.com/library/pil/handbook/formats.htm
@@ -481,10 +479,9 @@ class Drawing:
     def operator(self, operator='clear'):
         """Set the operator mode.
 
-        operator -- One of: clear
-                            source, over, in, out, atop
-                            dest, dest_over, dest_in, dest_out, dest_atop
-                            xor, add, saturate
+            operator
+                One of: clear, source, over, in, out, atop, dest,
+                dest_over, dest_in, dest_out, dest_atop, xor, add, saturate
 
         """
         ops = {'clear': cairo.OPERATOR_CLEAR,
@@ -513,7 +510,8 @@ class Drawing:
 
     def paint(self):
         """Paint the current source everywhere within the current clip
-        region."""
+        region.
+        """
         def _paint(cr):
             cr.paint()
         self.doStep(_paint)
@@ -524,13 +522,16 @@ class Drawing:
         region using a mask of constant alpha value alpha.
 
         The effect is similar to paint(), but the drawing is faded out
-        using the alpha value."""
+        using the alpha value.
+        """
         def _paint_with_alpha(cr):
             cr.paint_with_alpha(alpha)
         self.doStep(_paint_with_alpha, alpha)
 
+
     def point(self, x, y):
-        """Draw a point (really a tiny circle) at (x, y)."""
+        """Draw a point at (x, y).
+        """
         # Circle radius 1/1000 the drawing width
         radius = float(self.size[0]) / 1000
         def _point(cr):
@@ -554,7 +555,7 @@ class Drawing:
             nlist.append([tup])
         self.bezier(nlist, False, close_path)
 
-    
+
     def polyline(self, points, close_path=True):
         """Draw a polygon defined by (x, y) points in the given list.
 
@@ -564,7 +565,7 @@ class Drawing:
         """
         self.polygon(points, close_path)
 
-    
+
     def rectangle_corners(self, x0, y0, x1, y1):
         """Draw a rectangle defined by opposite corners (x0, y0) and (x1, y1).
         """
@@ -585,7 +586,8 @@ class Drawing:
 
 
     def rotate_deg(self, degrees):
-        """Rotate by the given number of degrees."""
+        """Rotate by the given number of degrees.
+        """
         def _rotate_deg(cr):
             m = cr.get_matrix()
             m.rotate(degrees * pi/180.)
@@ -593,10 +595,9 @@ class Drawing:
         self.doStep(_rotate_deg, degrees)
 
     rotate = rotate_deg
-
-
     def rotate_rad(self, rad):
-        """Rotate by the given number of radians."""
+        """Rotate by the given number of radians.
+        """
         def _rotate_rad(cr):
             m = cr.get_matrix()
             m.rotate(rad)
@@ -606,20 +607,20 @@ class Drawing:
 
     def roundrectangle(self, x0, y0, x1, y1, bevel_width, bevel_height):
         """Draw a rounded rectangle from (x0, y0) to (x1, y1), with
-        a bevel size of (bevel_width, bevel_height)."""
+        a bevel size of (bevel_width, bevel_height).
+        """
         bw = bevel_width
         bh = bevel_height
         # Add bezier points
-        # Top left corner:
-        tl1 = [(x0, y0 + bh), (0,0), (0,0)]
-        tl2 = [(x0 + bw, y0), (0,0), (-bw,0)]
-        tr1 = [(x1 - bw, y0), (0,0), (-bw,0)]
-        tr2 = [(x1, y0 + bh), (0,0), (0,-bw)]
-        br1 = [(x1, y1 - bh), (0,0), (0,-bh)]
-        br2 = [(x1 - bw, y1), (0,0), (+bw,0)]
-        bl1 = [(x0 + bw, y1), (0,0), (+bw,0)]
-        bl2 = [(x0, y1 - bh), (0,0), (0,+bh)]
-        end = [(x0, y0 + bh), (0,0), (0,0)]
+        tl1 = [(x0, y0 + bh), (0, 0), (0, 0)]
+        tl2 = [(x0 + bw, y0), (0, 0), (-bw, 0)]
+        tr1 = [(x1 - bw, y0), (0, 0), (-bw, 0)]
+        tr2 = [(x1, y0 + bh), (0, 0), (0, -bw)]
+        br1 = [(x1, y1 - bh), (0, 0), (0, -bh)]
+        br2 = [(x1 - bw, y1), (0, 0), (+bw, 0)]
+        bl1 = [(x0 + bw, y1), (0, 0), (+bw, 0)]
+        bl2 = [(x0, y1 - bh), (0, 0), (0, +bh)]
+        end = [(x0, y0 + bh), (0, 0), (0, 0)]
         # Call in relative mode bezier control points.
         mylst = [tl1, tl2, tr1, tr2, br1, br2, bl1, bl2, end]
         # Let bezier do the work
@@ -627,37 +628,41 @@ class Drawing:
 
 
     def set_source(self, source, opacity=None):
-        """
-        source -- One of the following color formats as a string or a tuple
-                  (see below), another Surface or Surface-derivative object,
-                  or a Pattern object (and its derivatives).
-        opacity -- Opacity ranging from 0.0 to 1.0. Defaults to None. If
-                   you specify a 'string' or 'tuple' RGB-like code as
-                   source, opacity defaults to 1.0
+        """Set the source.
+
+            source
+                One of the following color formats as a string or a tuple
+                (see below), another Surface or Surface-derivative object,
+                or a Pattern object (and its derivatives).
+            opacity
+                Opacity ranging from 0.0 to 1.0. Defaults to None. If
+                you specify a 'string' or 'tuple' RGB-like code as
+                source, opacity defaults to 1.0
 
         You can use the following *tuple* format to specify color:
-        * (red, green, blue) -- with colors ranging from 0.0 to 1.0, like
-                                Cairo wants them.
+
+        - (red, green, blue) with colors ranging from 0.0 to 1.0,
+          like Cairo wants them
 
         You can use the following *string* formats to specify color:
-        
-        * Hexadecimal color specifiers, given as '#rgb' or '#rrggbb'.
+
+        - Hexadecimal color specifiers, given as '#rgb' or '#rrggbb'.
           For example, '#ff0000' specifies pure red.
-        * RGB functions, given as 'rgb(red, green, blue)' where the colour
+        - RGB functions, given as 'rgb(red, green, blue)' where the colour
           values are integers in the range 0 to 255. Alternatively, the color
           values can be given as three percentages (0% to 100%). For example,
           'rgb(255,0,0)' and 'rgb(100%,0%,0%)' both specify pure red.
-        * Hue-Saturation-Lightness (HSL) functions, given as:
+        - Hue-Saturation-Lightness (HSL) functions, given as:
           'hsl(hue, saturation%, lightness%)' where hue is the colour given as
           an angle between 0 and 360 (red=0, green=120, blue=240), saturation
           is a value between 0% and 100% (gray=0%, full color=100%), and
           lightness is a value between 0% and 100% (black=0%, normal=50%,
           white=100%). For example, 'hsl(0,100%,50%)' is pure red.
-        * Common HTML colour names. The ImageColor module provides some 140
+        - Common HTML colour names. The ImageColor module provides some 140
           standard colour names, based on the colors supported by the X
           Window system and most web browsers. Colour names are case
           insensitive. For example, 'red' and 'Red' both specify pure red.
-         
+
         """
         mysource = self.create_source(source, opacity)
         def _set_source(cr):
@@ -776,7 +781,7 @@ class Drawing:
         """Enable/disable antialiasing for strokes.
 
             do_antialias: True, False, 'none', 'default', or 'gray'
-        
+
         This does not affect text. See text_antialias() for more info
         on text antialiasing.
         """
@@ -784,7 +789,7 @@ class Drawing:
             aa_type = cairo.ANTIALIAS_GRAY
         else:
             aa_type = cairo.ANTIALIAS_NONE
-            
+
         def _stroke_antialias(cr):
             cr.set_antialias(aa_type)
         self.doStep(_stroke_antialias, do_antialias)
@@ -793,13 +798,15 @@ class Drawing:
     def stroke_dash(self, array, offset=0.0):
         """Set the dash style.
 
-            array:  A list of floats, alternating between ON and OFF for
-                    each value
-            offset: An offset into the dash pattern at which the stroke
-                    should start
-        
-        For example:
-        
+            array
+                A list of floats, alternating between ON and OFF for
+                each value
+            offset
+                An offset into the dash pattern at which the stroke
+                should start
+
+        For example::
+
             >>> stroke_dash([5.0, 3.0])
 
         alternates between 5 pixels on, and 3 pixels off.
@@ -812,7 +819,8 @@ class Drawing:
     def stroke_linecap(self, cap_type):
         """Set the type of line cap to use for stroking.
 
-            cap_type:  One of 'butt', 'round', or 'square'
+            cap_type
+                'butt', 'round', or 'square'
         """
         dic = {'butt': cairo.LINE_CAP_BUTT,
                'round': cairo.LINE_CAP_ROUND,
@@ -820,7 +828,7 @@ class Drawing:
 
         # Test value
         dic[cap_type]
-        
+
         def _stroke_linecap(cr):
             cr.set_line_cap(dic[cap_type])
         self.doStep(_stroke_linecap, cap_type)
@@ -829,7 +837,8 @@ class Drawing:
     def stroke_linejoin(self, join_type):
         """Set the type of line-joining to do for stroking.
 
-            join_type:  One of 'bevel', 'miter', or 'round'.
+            join_type
+                'bevel', 'miter', or 'round'
         """
         dic = {'bevel': cairo.LINE_JOIN_BEVEL,
                'miter': cairo.LINE_JOIN_MITER,
@@ -837,7 +846,7 @@ class Drawing:
 
         # Test value
         dic[join_type]
-        
+
         def _stroke_linejoin(cr):
             cr.set_line_join(dic[join_type])
         self.doStep(_stroke_linejoin, join_type)
@@ -854,9 +863,11 @@ class Drawing:
     def text(self, text_string, x, y, align='left'):
         """Draw the given text string.
 
-            text_string: utf8 encoded text string
-            (x, y):      lower-left corner position
-        
+            text_string
+                utf8 encoded text string
+            x, y
+                lower-left corner position
+
         Set the text's color with set_source() before calling text().
         """
         text_string = to_unicode(text_string)
@@ -949,63 +960,33 @@ class Drawing:
         def _save(cr):
             cr.save()
         self.doStep(_save)
-    BEGIN = save
 
+    BEGIN = save
     def restore(self):
-        """Restore the previously saved context."""
+        """Restore the previously saved context.
+        """
         def _restore(cr):
             cr.restore()
         self.doStep(_restore)
+
     END = restore
-
-    ### ----------------------------------------------------------------
-    ### Untested methods
-    ### ----------------------------------------------------------------
-    
-    
-#    def font_slant(self, style):
-#        """Set the font slant. Use one of:
-#    
-#           normal, italic, oblique
-#        """
-#        tr = {'italic': cairo.FONT_SLANT_ITALIC,
-#              'normal': cairo.FONT_SLANT_NORMAL,
-#              'oblique': cairo.FONT_SLANT_OBLIQUE}
-#        def _font_slant(cr):
-#            cr.set_slant(tr[style])
-#        self.doStep(_font_slant, style)
-#    # Alias
-#    font_style = font_slant
-
-
-#    def font_weight(self, weight):
-#        """Set the font weight to one of:
-#        
-#            normal, bold
-#        """
-#        tr = {'normal': cairo.FONT_WEIGHT_NORMAL,
-#              'bold': cairo.FONT_WEIGHT_BOLD}
-#        def _font_weight(cr):
-#            cr.set_font_weight(tr[weight])
-#        self.doStep(_font_weight, weight)
-
-
     def font_family(self, family):
         """Set the current font, by family name."""
         def _font_family(cr):
             cr.select_font_face(family)
         self.doStep(_font_family, family)
-    # Alias
+
     font_face = font_family
-
-
     def text_align(self, text_string, x, y, align='left'):
         """Draw the given text string.
 
-            text_string: utf8 encoded text string
-            (x, y):      lower-left corner position
-            align:       'left', 'center', 'right'. This only changes the
-                         alignment in 'x', and 'y' stays the baseline.
+            text_string
+                UTF-8 encoded text string
+            x, y
+                Lower-left corner position
+            align
+                'left', 'center', 'right'. This only changes the
+                alignment in 'x', and 'y' stays the baseline.
 
         Set the text's color with set_source() before calling text().
         """
@@ -1033,65 +1014,9 @@ class Drawing:
         self.text_path(text_string, x, y)
 
 
-    #def gradient_units(self, units):
-    #    """Set gradient units to one of:
-    #    userSpace, userSpaceOnUse, objectBoundingBox
-    #    """
-    #    self.insert('gradient-units %s' % units)
-
-
-    #def gravity(self, direction):
-    #    """Set the gravity direction to one of:
-    #    
-    #        NorthWest, North, NorthEast,
-    #        West, Center, East,
-    #        SouthWest, South, SouthEast
-    #        
-    #    Note: gravity is known to affect text and images; it does not affect
-    #    points, lines, circles, rectangles, roundrectangles, polylines or
-    #    polygons.
-    #    """
-    #    self.insert('gravity %s' % direction)
-
-
-    #def matte(self, (x, y), method='floodfill'):
-    #    # method may be: point, replace, floodfill, filltoborder, reset
-    #    # (What do x, y mean?)
-    #    self.insert('matte %s,%s %s' % (x, y, method))
-
-
-    #def offset(self, offset):
-    #    self.insert('offset %s' % offset)
-
-
-    #def path(self, path_data):
-    #    """Draw a path. path_data is a list of instructions and coordinates,
-    #    e.g. ['M', (100,100), 'L', (200,200), ...]
-    #    Instructions are M (moveto), L (lineto), A (arc), Z (close path)
-    #    For more on using paths (and a complete list of commands), see:
-    #    http://www.cit.gu.edu.au/~anthony/graphics/imagick6/draw/#paths
-    #    http://www.w3.org/TR/SVG/paths.html#PathDataGeneralInformation
-    #    """
-    #    command = 'path'
-    #    for token in path_data:
-    #        if isinstance(token, tuple):
-    #            command += ' %s,%s' % token
-    #        else:
-    #            command += ' %s' % token
-    #    self.insert(command)
-
-
-    #def point(self, (x, y), size):
-    #    """Draw a point at position (x, y)"""
-    #    self.insert('point %s,%s' % (x, y))
-
-
-
 ### --------------------------------------------------------------------
 ### Exported functions
 ### --------------------------------------------------------------------
-
-
 # Cached masks, rendered only once.
 interlace_fields = None
 
@@ -1102,13 +1027,13 @@ def interlace_drawings(draw1, draw2):
     This method interlaces with the BOTTOM-FIRST field order.
     """
     global interlace_fields
-    
+
     dr = Drawing(draw1.w, draw1.h)
 
     # create masks (only once)
     if (not interlace_fields):
         fields = [0, 1]
-        for f in range(0,2):
+        for f in range(0, 2):
             img = cairo.ImageSurface(cairo.FORMAT_ARGB32, draw1.w, draw1.h)
             cr = cairo.Context(img)
             cr.set_antialias(cairo.ANTIALIAS_NONE)
@@ -1117,7 +1042,7 @@ def interlace_drawings(draw1, draw2):
 
             for x in range(0, draw1.h / 2):
                 # x*2 + f = top field first.., each two lines..
-                # -1  draw1.w +1 -> pour tre sur de couvrir aussi les bouts.
+                # -1 à draw1.w +1 -> pour être sur de couvrir aussi les bouts.
                 cr.move_to(-1, x*2 + f)
                 cr.line_to(draw1.w + 1, x*2 + f)
                 cr.stroke()
@@ -1130,9 +1055,9 @@ def interlace_drawings(draw1, draw2):
     # For bottom first, use fields[0] first, and fields[1] after.
     # For top-first, use draw1 with fields[1] and draw2 with fields[0]
     # paint first image
-    dr.image_surface(0,0,dr.w, dr.h, draw1.surface, fields[0])
+    dr.image_surface(0, 0, dr.w, dr.h, draw1.surface, fields[0])
     # paint second image
-    dr.image_surface(0,0,dr.w, dr.h, draw2.surface, fields[1])
+    dr.image_surface(0, 0, dr.w, dr.h, draw2.surface, fields[1])
 
     return dr
 
@@ -1147,7 +1072,7 @@ def render(drawing, context, width, height):
     drawing.scale(scale_x, scale_y)
     # Sneaky bit--scaling needs to happen before everything else
     drawing.steps.insert(0, drawing.steps.pop(-1))
-    
+
     # Execute all draw commands
     for step in drawing.steps:
         log.debug("Drawing step: %s" % step)
@@ -1159,14 +1084,18 @@ def render(drawing, context, width, height):
 
 def display(drawing, width=None, height=None, fix_aspect=False):
     """Render and display the given Drawing at the given size.
-    
-        drawing:    A Drawing object to display
-        width:      Pixel width of displayed image,
-                    or 0 to use the given Drawing's size
-        height:     Pixel height of displayed image,
-                    or 0 to use the given Drawing's size
-        fix_aspect: True to adjust height to make the image
-                    appear in the correct aspect ratio
+
+        drawing
+            A Drawing object to display
+        width
+            Pixel width of displayed image,
+            or 0 to use the given Drawing's size
+        height
+            Pixel height of displayed image,
+            or 0 to use the given Drawing's size
+        fix_aspect
+            True to adjust height to make the image
+            appear in the correct aspect ratio
     """
     if not width:
         width = drawing.size[0]
@@ -1179,47 +1108,51 @@ def display(drawing, width=None, height=None, fix_aspect=False):
     # Render and display a .png
     png_file = '/tmp/drawing.png'
     save_png(drawing, png_file, width, height)
-    print "Displaying", png_file, "at %sx%s" % (width, height)
-    print "(press 'q' in image window to continue)"
-    print commands.getoutput('display %s' % png_file)
+    print("Displaying %s at %sx%s" % (png_file, width, height))
+    print("(press 'q' in image window to continue)")
+    print(commands.getoutput('display %s' % png_file))
 
 
 def write_ppm(drawing, pipe, width, height, workdir=None):
     """Write image as a PPM file to a file-object
 
-      workdir - Unused in this context, just to have parallel parameters
-                with write_png().
+      workdir
+        Unused in this context, just to have parallel parameters
+        with write_png().
 
     Useful to pipe directly in ppmtoy4m and to pipe directly to mpeg2enc.
     """
     # Timing
     start = time.time()
     if (width, height) == drawing.size:
-        #print "Not re-rendering"
+        #print("Not re-rendering")
         surface = drawing.surface
     else:
         surface = get_surface(width, height, 'image')
         context = cairo.Context(surface)
         render(drawing, context, width, height)
-        
+
     buf = surface.get_data()
     # Assumes surface is cairo.FORMAT_ARGB32
     im = Image.frombuffer('RGBA', (surface.get_width(),  surface.get_height()),
                           buf)
     im = im.transpose(Image.FLIP_TOP_BOTTOM)
     im.save(pipe, 'ppm')
-    
-    print "write_ppm took %s seconds" % (time.time() - start)
-    
+
+    #print("write_ppm took %s seconds" % (time.time() - start))
+
+
 def write_png(drawing, pipe, width, height, workdir):
     """Write image as a PPM file to a file-object
 
-    Useful to pipe directly in pngtopnm -mix -background=rgb:00/00/00 | ppmtoy4m | mpeg2enc.
+    Useful to pipe directly in::
+
+        pngtopnm -mix -background=rgb:00/00/00 | ppmtoy4m | mpeg2enc.
     """
     # Timing
     start = time.time()
     if (width, height) == drawing.size:
-        #print "Not re-rendering"
+        #print("Not re-rendering")
         surface = drawing.surface
     else:
         surface = get_surface(width, height, 'image')
@@ -1230,27 +1163,26 @@ def write_png(drawing, pipe, width, height, workdir):
     im = Image.open('%s/tmp.png' % workdir)
     im.load()
     im.save(pipe, 'ppm')
-    
-    print "write_png took %s seconds" % (time.time() - start)
-
 
+    #print("write_png took %s seconds" % (time.time() - start))
 
 
 def save_png(drawing, filename, width, height):
     """Saves a drawing to PNG, keeping alpha channel intact.
 
-    This is the quickest, since Cairo itself exports directly to .png"""
+    This is the quickest, since Cairo itself exports directly to .png
+    """
     # Timing
     start = time.time()
     if (width, height) == drawing.size:
-        print "Not re-rendering"
+        #print("Not re-rendering")
         surface = drawing.surface
     else:
         surface = get_surface(width, height, 'image')
         context = cairo.Context(surface)
         render(drawing, context, width, height)
     surface.write_to_png(filename)
-    print "save_png took %s seconds" % (time.time() - start)
+    #print("save_png took %s seconds" % (time.time() - start))
 
 
 def save_jpg(drawing, filename, width, height):
@@ -1266,7 +1198,8 @@ def save_jpg(drawing, filename, width, height):
 
 
 def save_image(drawing, img_filename, width, height):
-    """Render drawing to a .jpg, .png or other image."""
+    """Render drawing to a .jpg, .png or other image.
+    """
     log.info("Saving Drawing to %s" % img_filename)
     if img_filename.endswith('.png'):
         save_png(drawing, img_filename, width, height)
@@ -1279,67 +1212,71 @@ def save_image(drawing, img_filename, width, height):
         log.debug("Converting temporary png to %s" % img_filename)
         cmd = "convert -size %sx%s " % drawing.size
         cmd += "%s %s" % (temp_png, img_filename)
-        print commands.getoutput(cmd)
+        print(commands.getoutput(cmd))
 
 
 def save_svg(drawing, filename, width, height):
-    """Render drawing to an SVG file."""
+    """Render drawing to an SVG file.
+    """
     surface = get_surface(width, height, 'svg', filename)
     context = cairo.Context(surface)
     render(drawing, context, width, height)
     context.show_page()
     surface.finish()
-    print "Saved SVG to", filename
+    print("Saved SVG to %s" % filename)
 
 
 def save_pdf(drawing, filename, width, height):
-    """Render drawing to a PDF file."""
+    """Render drawing to a PDF file.
+    """
     surface = get_surface(width, height, 'pdf', filename)
     context = cairo.Context(surface)
     render(drawing, context, width, height)
     context.show_page()
     surface.finish()
-    print "Saved PDF to", filename
+    print("Saved PDF to %s" % filename)
 
 
 def save_ps(drawing, filename, width, height):
-    """Render drawing to a PostScript file."""
+    """Render drawing to a PostScript file.
+    """
     surface = get_surface(width, height, 'ps', filename)
     context = cairo.Context(surface)
     render(drawing, context, width, height)
     context.show_page()
     surface.finish()
-    print "Saved PostScript to", filename
+    print("Saved PostScript to %s" % filename)
 
 
 ### --------------------------------------------------------------------
 ### Demo functions
 ### --------------------------------------------------------------------
-
 def draw_fontsize_demo(drawing):
-    """Draw font size samples on the given drawing."""
+    """Draw font size samples on the given drawing.
+    """
     assert isinstance(drawing, Drawing)
 
     # Save context
     drawing.save()
     # TODO: Remove this scaling hack
     drawing.scale(800.0/720, 600.0/480)
-    
+
     # Draw white text in a range of sizes
     drawing.set_source('white')
-    
-    for size in [12,16,20,24,28,32]:
+
+    for size in [12, 16, 20, 24, 28, 32]:
         ypos = size * size / 5
         drawing.font('Nimbus Sans')
         drawing.font_size(size)
         drawing.text("%s pt: The quick brown fox" % size, 700, ypos, 'right')
-    
+
     # Restore context
     drawing.restore()
 
 
 def draw_font_demo(drawing):
-    """Draw samples of different fonts on the given drawing."""
+    """Draw samples of different fonts on the given drawing.
+    """
     assert isinstance(drawing, Drawing)
 
     # Save context
@@ -1378,7 +1315,8 @@ def draw_font_demo(drawing):
 
 
 def draw_shape_demo(drawing):
-    """Draw shape samples on the given drawing."""
+    """Draw shape samples on the given drawing.
+    """
     assert isinstance(drawing, Drawing)
 
     # Save context
@@ -1407,16 +1345,16 @@ def draw_shape_demo(drawing):
     # drawing.circle((65, 150), 5)
     # drawing.set_style(fill='black') # stroke stays the same as before
     # drawing.rectangle((40, 30), (50, 150))
-    
+
     drawing.stroke_width(2)
     drawing.circle(65, 50, 15)
     drawing.fill('#8080FF')
     drawing.stroke('#777')
-    
+
     drawing.circle(60, 100, 10)
     drawing.fill('#2020F0')
     drawing.stroke('#777')
-    
+
     drawing.circle(55, 150, 5)
     drawing.fill('#0000A0')
     drawing.stroke('#777')
@@ -1443,14 +1381,15 @@ def draw_shape_demo(drawing):
 
 
 def draw_stroke_demo(drawing):
-    """Draw a stroke/strokewidth demo on the given drawing."""
+    """Draw a stroke/strokewidth demo on the given drawing.
+    """
     assert isinstance(drawing, Drawing)
 
     # Save context
     drawing.save()
     # TODO: Remove this scaling hack
     drawing.scale(800.0/720, 600.0/480)
-    
+
     for width in [1, 2, 4, 6, 8, 10, 12, 14, 16]:
         drawing.stroke_width(width)
         rgb = ((255 - width * 8), (120 - width * 5), 0)
@@ -1461,7 +1400,6 @@ def draw_stroke_demo(drawing):
     # Restore context
     drawing.restore()
 
-log.level = 'info'
 
 if __name__ == '__main__':
     mytime = time.time() # Benchmark
@@ -1502,7 +1440,7 @@ if __name__ == '__main__':
     # Close out the Cairo rendering...
     drawing.restore()
 
-    print "Took %f seconds" % (time.time() - mytime)
+    print("Took %f seconds" % (time.time() - mytime))
 
     # Render and display the Drawing at several different sizes
     resolutions = [(352, 240), (352, 480), (720, 480), (800, 600)]
