@@ -1,25 +1,19 @@
-#! /usr/bin/env python
-# flipbook.py
-
-"""This module provides the Flipbook class.
+"""This module provides the Flipbook class, a collection of drawings that, when
+displayed in sequence, make up an animation or video.
 
 Run this module standalone for a demonstration:
 
-    $ python libtovid/flipbook.py
-
-Much like a paper flipbook made of many individual drawings, the Flipbook class
-has a collection of Drawing objects (from libtovid/renderers/mvg_render.py) that,
-when displayed in sequence, make up an animation or video.
+    $ python flipbook.py
 
 To use this module interactively, run 'python' from the command-line, and do:
 
-    >>> from libtovid.flipbook import Flipbook
+    >>> from libtovid.render.flipbook import Flipbook
 
 To create a Flipbook 10 seconds long with 'dvd' and 'ntsc' standards, do:
 
     >>> flipbook = Flipbook(10, 'dvd', 'ntsc', '4:3')
 
-Then you can retrieve the canvas width and height with:
+You can retrieve the canvas width and height with:
 
     >>> flipbook.canvas
     (640, 480)
@@ -28,10 +22,10 @@ Then you can retrieve the canvas width and height with:
     >>> flipbook.h
     480
 
-All drawing upon a Flipbook is achieved through the use of layers
-(libtovid/layer.py). To use them, import the layer module:
+All drawing upon a Flipbook is achieved through the use of layers (layer.py).
+To use them, import the layer module:
 
-    >>> from libtovid import layer
+    >>> from libtovid.render import layer
 
 You can add layers to a Flipbook on-the-fly:
 
@@ -44,10 +38,9 @@ Or, create layers separately before adding them to the Flipbook:
     >>> flipbook.add(text)
 
 This latter approach is useful if you plan to apply animation effects to the
-Layer. For this, effects classes (libtovid/effect.py) may be applied. First,
-import:
+Layer. For this, effects classes (effect.py) may be applied. First, import:
 
-    >>> from libtovid import effect
+    >>> from libtovid.render import effect
 
 Now, say we want the text "Elephant talk" to move across the screen, say from
 (100, 100) to (500, 100) over the course of the first 90 frames. The
@@ -77,12 +70,13 @@ import cairo
 import shutil
 import random
 from libtovid.render.animation import Keyframe
-from libtovid.render.drawing import Drawing, write_ppm, write_png, interlace_drawings
+from libtovid.render.drawing import Drawing, interlace_drawings
+from libtovid.render.drawing import write_ppm, write_png, save_png
 from libtovid.render import layer, effect
 from libtovid import standard
-from libtovid.media import MediaFile, standard_media, load_media
-from libtovid.transcode import encode
-from libtovid import utils
+from libtovid.media import MediaFile
+from libtovid.backend import mplex, mplayer, ffmpeg
+
 
 class Flipbook:
     """A collection of Drawings that together comprise an animation.
@@ -91,14 +85,17 @@ class Flipbook:
         """Create a flipbook of the given length in seconds, at the given
         resolution.
 
-            seconds: Length of flipbook playback in seconds
-            format:  'dvd', 'vcd', 'svcd', 'dvd-vcd', or 'half-dvd'
-            tvsys:   'ntsc' or 'pal'
-            aspect:  '4:3' or '16:9' (the latter only for format='dvd')
-                     (default: '4:3')
-            interlaced: True/False. When enabled, the framerate will be
-                     doubled, but only half the frames (twice the fields)
-                     will be rendered.
+            seconds
+                Length of flipbook playback in seconds
+            format
+                'dvd', 'vcd', 'svcd', 'dvd-vcd', or 'half-dvd'
+            tvsys
+                'ntsc' or 'pal'
+            aspect
+                '4:3' or '16:9' (the latter only for format='dvd')
+            interlaced
+                True/False. When enabled, the framerate will be doubled,
+                but only half the frames (twice the fields) will be rendered.
 
         Once you've created the Flipbook, you can grab the dimensions
         in with the property:
@@ -115,7 +112,7 @@ class Flipbook:
             self.tmpdir = os.environ['TMPDIR']
         self.seconds = float(seconds)
         self.fps = standard.fps(tvsys)
-        self.fpsratio = standard.fpsratio(tvsys)
+        self.fps_ratio = standard.fps_ratio(tvsys)
         if (interlaced):
             self.fps *= 2
         self.interlaced = interlaced
@@ -130,8 +127,8 @@ class Flipbook:
         self.widescreen = False
         if (aspect == '16:9'):
             self.widescreen = True
-            
-        self.canvas = self._get_canvas_size()
+
+        self.canvas = self.get_canvas_size()
         self.w = self.canvas[0]
         self.h = self.canvas[1]
 
@@ -139,11 +136,10 @@ class Flipbook:
         self.layers = []
         self.drawings = []
 
-        self._called_init_childs = False
+        self.called_init_childs = False
 
 
-    ### Child-parent handling
-    def _init_childs(self):
+    def init_childs(self):
         """Give access to all descendant layers and effects to their parents.
 
         In layers, you can access your parent layer (if sublayed) with:
@@ -157,20 +153,22 @@ class Flipbook:
         It's also called in emergency if you call directly get_drawing().
         """
         for x in range(0, len(self.layers)):
-            self.layers[x][0]._init_parent_flipbook(self)
-            self.layers[x][0]._init_childs()
+            self.layers[x][0].init_parent_flipbook(self)
+            self.layers[x][0].init_childs()
+
+        self.called_init_childs = True
 
-        self._called_init_childs = True
-        
-        
-    # Utility functions
 
     def stof(self, seconds):
-        """Return the number of frames to the specified time (in seconds)"""
+        """Return the number of frames to the specified time (in seconds).
+        """
         return int(self.fps * float(seconds))
 
-    def _get_canvas_size(self):
-        ow = self.output_size[0]
+
+    def get_canvas_size(self):
+        """Return the dimensions of the canvas.
+        """
+        #ow = self.output_size[0]
         oh = self.output_size[1]
         a = self.aspect.split(':')
 
@@ -184,23 +182,26 @@ class Flipbook:
         # since on TVs, the number of *lines* can't change (when interlacing
         # is into business)
         return (nw, oh)
-        
+
 
     def add(self, layer, position=(0, 0)):
-        """Add a Layer to the flipbook."""
+        """Add a Layer to the flipbook.
+        """
         self.layers.append((layer, position))
 
-    def render(self, frame=1):
-        """Render the given frame."""
 
-        print "DEPRECATED FUNCTION."
+    def render(self, frame=1):
+        """Render the given frame.
+        """
+        print("DEPRECATED FUNCTION.")
         exit()
-        
+
         filename = "/tmp/flipbook_%s.png" % frame
-        print "Rendering Flipbook frame %s to %s" % (frame, filename)
+        print("Rendering Flipbook frame %s to %s" % (frame, filename))
         drawing = self.get_drawing(frame)
 
-        drawing.save_png(filename, self.output_size[0], self.output_size[1])
+        save_png(drawing, filename, self.output_size[0], self.output_size[1])
+
 
     def get_drawing(self, frame):
         """Get a Drawing of the given frame
@@ -209,9 +210,9 @@ class Flipbook:
         """
 
         # Make sure all layers and effects has been initialized with parents.
-        if (not self._called_init_childs):
-            self._init_childs()
-            
+        if (not self.called_init_childs):
+            self.init_childs()
+
         drawing = Drawing(self.canvas[0], self.canvas[1])
         # Draw each layer
         for layer, position in self.layers:
@@ -226,14 +227,14 @@ class Flipbook:
     def render_video(self, out_filename=None):
         """Render the flipbook to an .m2v video stream file.
 
-            out_filename:    Filename for output.
-                             If not specified, a temporary filename
-                             will be given, and returned from the function.
-        
+            out_filename
+                Filename for output. If not specified, a temporary filename
+                will be given, and returned from the function.
+
         Return the filename of the output, in both cases.
         """
-        ## Make sure layers and effects have been initialized with parents.
-        self._init_childs()
+        # Make sure layers and effects have been initialized with parents.
+        self.init_childs()
 
         #
         # if self.tmpdir = /tmp, we get:
@@ -242,10 +243,11 @@ class Flipbook:
         # /tmp/flipbook-120391232-work/bunch-of-files..m2v, .ac3, etc.
         # /tmp/flipbook-120391232.mpg -> final output..
         #
-        
-        tmp_prefix = '';tmp_workdir = '';
+
+        tmp_prefix = ''
+        tmp_workdir = ''
         while 1:
-            rnd = random.randint(1000000,9999999)
+            rnd = random.randint(1000000, 9999999)
             tmp_prefix = "%s/flipbook-%s" % (self.tmpdir, rnd)
             tmp_workdir = "%s-work" % (tmp_prefix)
 
@@ -264,14 +266,15 @@ class Flipbook:
 
 
         try:
-            cairo.ImageSurface.get_data
-
-            pngorpnm = 'ppmtoy4m -F %s -A %s -Ip -B -S 420mpeg2' % (self.fpsratio, self.aspect)
+            #cairo.ImageSurface.get_data
+            pngorpnm = 'ppmtoy4m -F %s -A %s -Ip -B -S 420mpeg2' % \
+                     (self.fps_ratio, self.aspect)
             _write_img = write_ppm  # set write function just below
         except:
-            pngorpnm = 'ppmtoy4m -F %s -A %s -Ip -S 420mpeg2' % (self.fpsratio, self.aspect)
+            pngorpnm = 'ppmtoy4m -F %s -A %s -Ip -S 420mpeg2' % \
+                     (self.fps_ratio, self.aspect)
             _write_img = write_png
-            
+
         # Cinelerra params: -b 0 -q 5 -a 2 -F 4 -I 0 -M 2 -f 8 -R 0
         # TODO: move this to encode.py
         # -M (multi-threading, num CPUs)
@@ -279,14 +282,13 @@ class Flipbook:
         # -b 0 -q 5
         #    or
         # -b 7500
-        pipe = os.popen("%s | mpeg2enc -q 5 -g 45 -G 45 -f 8 -a 2 -I 0 -o '%s'" % (pngorpnm,  m2v_file), 'w')
-        
+        pipe = os.popen("%s | mpeg2enc -q 5 -g 45 -G 45 -f 8 -a 2 -I 0 "
+                        "-o '%s'" % (pngorpnm,  m2v_file), 'w')
+
         frame = 1
         while frame <= self.frames:
-            print "Drawing frame %s of %s" % (frame, self.frames)
-            # Il faudra ici sauver DEUX drawing si on est en mode entrelacé, puis
-            # les combiner en UN drawing avant de rendre en .PNG.
-            # Entre les deux, on alterne les MASKS, ligne à ligne, etc..
+            print("Drawing frame %s of %s" % (frame, self.frames))
+
             if (self.interlaced):
                 draw1 = self.get_drawing(frame)
                 frame += 1
@@ -297,21 +299,23 @@ class Flipbook:
                 drawing = self.get_drawing(frame)
 
             # jpeg2yuv likes frames to start at 0
-                _write_img(drawing, pipe, self.output_size[0], self.output_size[1], tmp_workdir)
-                
+                _write_img(drawing, pipe,
+                           self.output_size[0], self.output_size[1],
+                           tmp_workdir)
+
             frame += 1
 
-        print "Closing encoder. Output to %s" % out_filename
+        print("Closing encoder. Output to %s" % out_filename)
         pipe.close()
 
-        print "Waiting for encoder to finish..."
+        print("Waiting for encoder to finish...")
         time.sleep(0.5)
 
         os.system("ls -al %s" % m2v_file)
         os.system("cp %s /tmp/go.m2v" % m2v_file)
-        vidonly = load_media(m2v_file)
+        vidonly = mplayer.identify(m2v_file)
 
-        # FIX the length of the load_media's bad ass..
+        # Fix length
         vidonly.length = float(self.seconds)
 
         outvid = MediaFile(out_filename, self.format, self.tvsys)
@@ -319,28 +323,27 @@ class Flipbook:
         # Important to render 16:9 video correctly.
         outvid.widescreen = self.widescreen
 
-        print "Running audio encoder..."
-        encode.encode_audio(vidonly, ac3_file, outvid)
+        print("Running audio encoder...")
+        ffmpeg.encode_audio(vidonly, ac3_file, outvid)
 
-        print "Mplex..."
-        encode.mplex_streams(m2v_file, ac3_file, outvid)
+        print("Mplex...")
+        mplex.mux(m2v_file, ac3_file, outvid)
 
         # Clean up
-        print "Cleaning up %s ..." % tmp_workdir
+        print("Cleaning up %s ..." % tmp_workdir)
         shutil.rmtree(tmp_workdir)
 
-        print "Output: %s" % out_filename
+        print("Output: %s" % out_filename)
         return out_filename
 
 
-        
-
 def draw_text_demo(flipbook):
-    """Draw a demonstration of Text layers with various effects."""
+    """Draw a demonstration of Text layers with various effects.
+    """
     assert isinstance(flipbook, Flipbook)
 
     last_frame = flipbook.frames
-    
+
     # Background image
     bgd = layer.Background('black')
     flipbook.add(bgd)
@@ -366,11 +369,11 @@ def draw_text_demo(flipbook):
          Keyframe(55, -2),
          Keyframe(60, 0)]
     text4.add_effect(effect.Whirl(k, center=(25, 10), units='deg'))
-    text4.add_effect(effect.Colorfade(1, last_frame, (1.0,0,0), (0, 1.0, 0)))
+    text4.add_effect(effect.Colorfade(1, last_frame, (1.0, 0, 0), (0, 1.0, 0)))
     flipbook.add(text4, (340, 350))
 
     text5 = layer.Text(u'Whirl effect demo2 ', color='white', align="center")
-    k2 = [Keyframe(0,0),
+    k2 = [Keyframe(0, 0),
           Keyframe(last_frame, 720)]
     text5.add_effect(effect.Whirl(k2, center=(25, 10), units='deg'))
     flipbook.add(text5, (450, 400))
@@ -400,7 +403,7 @@ def draw_text_demo(flipbook):
     flipbook.add(text_cosine, (340, 150))
     flipbook.add(graph_cosine, (340, 180))
 
-# Demo
+
 if __name__ == '__main__':
     start_time = time.time() # Benchmark
 
@@ -417,9 +420,9 @@ if __name__ == '__main__':
     #clip.rip_frames(0, 90)
     #clip.effects.append(effect.Fade(1, 90, 20))
     #flip.add(clip, (260, 200))
-    
+
     # Render the final video
     filename = flip.render_video('/tmp/flipbook.mpg')
 
-    print "Took %f seconds to render: %s" % (time.time() - start_time, filename)
-    
+    print("Took %f seconds to render: %s" % (time.time() - start_time, filename))
+
