@@ -1,6 +1,3 @@
-#! /usr/bin/env python
-# layer.py
-
 """This module provides a Layer class and several derivatives. A Layer
 is a graphical overlay that may be composited onto an image canvas.
 
@@ -18,7 +15,7 @@ function. For more on how to use Layers, see the Layer class definition and
 template example below.
 """
 
-__all__ = [\
+__all__ = [
     'Layer',
     'Background',
     'Text',
@@ -32,22 +29,21 @@ __all__ = [\
     'SafeArea',
     'Scatterplot',
     'InterpolationGraph',
-    'ColorBars']
+    'ColorBars',
+]
 
 import os
 import sys
 import math
 import commands
-from libtovid.utils import get_file_type
+from libtovid.util import get_file_type
 from libtovid.render.drawing import Drawing, save_image
 from libtovid.render.effect import Effect
 from libtovid.render.animation import Keyframe, Tween
 from libtovid.media import MediaFile
-from libtovid.transcode import rip
+from libtovid.backend import transcode
 from libtovid import log
 
-log.level = 'info'
-
 class Layer:
     """A visual element, or a composition of visual elements. Conceptually
     similar to a layer in the GIMP or Photoshop, with support for animation
@@ -56,7 +52,8 @@ class Layer:
     def __init__(self):
         """Initialize the layer. Extend this in derived classes to accept
         configuration settings for drawing the layer; call this function
-        from any derived __init__ functions."""
+        from any derived __init__ functions.
+        """
         self.effects = []
         self.sublayers = []
         self._parent_flipbook = None
@@ -65,7 +62,7 @@ class Layer:
     ###
     ### Child-parent initialization
     ###
-    def _init_childs(self):
+    def init_childs(self):
         """Give access to all descendant layers and effects to their parents.
 
         In layers, you can access your parent layer (if sublayed) with:
@@ -74,33 +71,34 @@ class Layer:
             layer._parent_flipbook
         """
         for x in range(0, len(self.effects)):
-            self.effects[x]._init_parent_flipbook(self._parent_flipbook)
-            self.effects[x]._init_parent_layer(self)
+            self.effects[x].init_parent_flipbook(self._parent_flipbook)
+            self.effects[x].init_parent_layer(self)
         for x in range(0, len(self.sublayers)):
-            self.sublayers[x][0]._init_parent_flipbook(self._parent_flipbook)
-            self.sublayers[x][0]._init_parent_layer(self)
-            self.sublayers[x][0]._init_childs(self)
+            self.sublayers[x][0].init_parent_flipbook(self._parent_flipbook)
+            self.sublayers[x][0].init_parent_layer(self)
+            self.sublayers[x][0].init_childs(self)
 
-    def _init_parent_flipbook(self, flipbook):
+    def init_parent_flipbook(self, flipbook):
         self._parent_flipbook = flipbook
 
-    def _init_parent_layer(self, layer):
+    def init_parent_layer(self, layer):
         self._parent_layer = layer
 
 
     ###
     ### Derived-class interface
     ###
-    
+
     def draw(self, drawing, frame):
         """Draw the layer and all sublayers onto the given Drawing. Override
-        this function in derived layers."""
+        this function in derived layers.
+        """
         assert isinstance(drawing, Drawing)
 
     ###
     ### Sublayer and effect interface
     ###
-    
+
     def add_sublayer(self, layer, position=(0, 0)):
         """Add the given Layer as a sublayer of this one, at the given position.
         Sublayers are drawn in the order they are added; each sublayer may have
@@ -110,11 +108,12 @@ class Layer:
         self.sublayers.append((layer, position))
 
     def draw_sublayers(self, drawing, frame):
-        """Draw all sublayers onto the given Drawing for the given frame."""
+        """Draw all sublayers onto the given Drawing for the given frame.
+        """
         assert isinstance(drawing, Drawing)
         for sublayer, position in self.sublayers:
             drawing.save()
-            drawing.translate(position)
+            drawing.translate(*position)
             sublayer.draw(drawing, frame)
             drawing.restore()
 
@@ -127,10 +126,10 @@ class Layer:
 
     def draw_with_effects(self, drawing, frame):
         """Render the entire layer, with all effects applied.
-        
+
             drawing: A Drawing object to draw the Layer on
             frame:   The frame number that is being drawn
-            
+
         """
         # Do preliminary effect rendering
         for effect in self.effects:
@@ -142,9 +141,8 @@ class Layer:
             effect.post_draw(drawing, frame)
 
 
-# ============================================================================
 # Layer template
-# ============================================================================
+#
 # Copy and paste the following code to create your own Layer.
 #
 # Layer subclasses should define two things:
@@ -154,10 +152,10 @@ class Layer:
 #
 # First, declare the layer class name. Include (Layer) to indicate that your
 # class is a Layer.
+
 class MyLayer (Layer):
     """Overlapping semitransparent rectangles.
     (Modify this documentation string to describe what's in your layer)"""
-
     # Here's the class initialization function, __init__. Define here any
     # parameters that might be used to configure your layer's behavior or
     # appearance in some way (along with default values, if you like). Here,
@@ -208,13 +206,6 @@ class MyLayer (Layer):
         # Be sure to restore the drawing context afterwards:
         drawing.restore()
 
-    # That's it! Your layer is ready to use. See the Demo section at the end of
-    # this file for examples on how to create and render Layers using Python.
-
-# ============================================================================
-# End of Layer template
-# ============================================================================
-
 
 class Background (Layer):
     """A background that fills the frame with a solid color, or an image."""
@@ -222,7 +213,7 @@ class Background (Layer):
         Layer.__init__(self)
         self.color = color
         self.filename = filename
-        
+
     def draw(self, drawing, frame):
         assert isinstance(drawing, Drawing)
         log.debug("Drawing Background")
@@ -238,13 +229,12 @@ class Background (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class Image (Layer):
     """A rectangular image, scaled to the given size.
 
-    image_source -- can be anything Drawing::image() can accept.
-                    See documentation in render/drawing.py.
+        image_source
+            Can be anything Drawing::image() can accept.
+            See documentation in render/drawing.py.
     """
     def __init__(self, image_source, (x, y), (width, height)):
         Layer.__init__(self)
@@ -266,15 +256,14 @@ class Image (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class VideoClip (Layer):
     """A rectangular video clip, scaled to the given size.
 
     TODO: num_frames should accept a range [first, end], an int (1-INT) and
     rip frames accordingly. For now, it only accepts an INT for the range 1-INT
     """
-    def __init__(self, filename, (width, height), position=(0,0), num_frames=120):
+    def __init__(self, filename, (width, height),
+                 position=(0, 0), num_frames=120):
         Layer.__init__(self)
         self.filename = filename
         self.mediafile = MediaFile(filename)
@@ -291,13 +280,13 @@ class VideoClip (Layer):
         """Rip frames from the video file, from start to end frames."""
         log.info("VideoClip: Ripping frames %s to %s" % (start, end))
         outdir = '/tmp/%s_frames' % self.filename
-        self.frame_files = rip.rip_frames(self.mediafile, outdir,
+        self.frame_files = transcode.rip_frames(self.mediafile, outdir,
                                           [start, end])
 
     def draw(self, drawing, frame=1):
         """Draw ripped video frames to the given drawing. For now, it's
         necessary to call rip_frames() before calling this function.
-        
+
         Video is looped.
         """
         assert isinstance(drawing, Drawing)
@@ -314,15 +303,16 @@ class VideoClip (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class Text (Layer):
     """A simple text string, with size, color and font.
-
-    text -- UTF8 encoded string.
     """
     def __init__(self, text, position=(0, 0), color='white', fontsize=20, \
                  font='Helvetica', align='left'):
+        """Create a Text layer.
+
+            text
+                UTF8 encoded string.
+        """
         Layer.__init__(self)
         self.text = text
         self.color = color
@@ -334,7 +324,8 @@ class Text (Layer):
 
     # TODO: This is gonna be pretty broken...
     def extents(self, drawing):
-        """Return the extents of the text as a (x0, y0, x1, y1) tuple."""
+        """Return the extents of the text as a (x0, y0, x1, y1) tuple.
+        """
         assert isinstance(drawing, Drawing)
         drawing.save()
         drawing.font(self.font)
@@ -363,12 +354,8 @@ class Text (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class ShadedText (Layer):
     """A simple text string, with size, color and font.
-
-    text -- UTF8 encoded string.
     """
     def __init__(self, text, position=(0, 0), offset=(5, 5),
                  color='white', shade_color='gray', fontsize=20,
@@ -389,13 +376,12 @@ class ShadedText (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class Label (Text):
     """A text string with a rectangular background.
 
-    You can access Text's extents() function from within here too."""
-    def __init__(self, text, position=(0,0), color='white', bgcolor='#555',
+    You can access Text's extents() function from within here too.
+    """
+    def __init__(self, text, position=(0, 0), color='white', bgcolor='#555',
                  fontsize=20, font='NimbusSans'):
         Text.__init__(self, text, position, color, fontsize, font)
         self.bgcolor = bgcolor
@@ -435,11 +421,10 @@ class Label (Text):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class Thumb (Layer):
-    """A thumbnail image or video."""
-    def __init__(self, filename, (width, height), position=(0,0), title=''):
+    """A thumbnail image or video.
+    """
+    def __init__(self, filename, (width, height), position=(0, 0), title=''):
         Layer.__init__(self)
         self.filename = filename
         self.size = (width, height)
@@ -468,15 +453,13 @@ class Thumb (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class ThumbGrid (Layer):
     """A rectangular array of thumbnail images or videos."""
     def __init__(self, files, titles=None, (width, height)=(600, 400),
                  (columns, rows)=(0, 0), aspect=(4,3)):
         """Create a grid of thumbnail images or videos from a list of files,
         fitting in a space no larger than the given size, with the given number
-        of columns and rows. Use 0 to auto-layout columns or rows, or both 
+        of columns and rows. Use 0 to auto-layout columns or rows, or both
         (default).
         """
         assert files != []
@@ -539,15 +522,13 @@ class ThumbGrid (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class SafeArea (Layer):
     """Render a safe area box at a given percentage.
     """
     def __init__(self, percent, color):
         self.percent = percent
         self.color = color
-        
+
     def draw(self, drawing, frame=1):
         assert isinstance(drawing, Drawing)
         log.debug("Drawing SafeArea")
@@ -571,16 +552,13 @@ class SafeArea (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class Scatterplot (Layer):
     """A 2D scatterplot of data.
-
-    Untested since MVG move.
     """
     def __init__(self, xy_dict, width=240, height=80, x_label='', y_label=''):
         """Create a scatterplot using data in xy_dict, a dictionary of
-        lists of y-values, indexed by x-value."""
+        lists of y-values, indexed by x-value.
+        """
         self.xy_dict = xy_dict
         self.width, self.height = (width, height)
         self.x_label = x_label
@@ -611,7 +589,7 @@ class Scatterplot (Layer):
         drawing.save()
         drawing.rectangle(0, 0, width, height)
         drawing.fill('white', 0.75)
-        
+
         # Draw axes
         #->comment("Axes of scatterplot")
         drawing.save()
@@ -666,22 +644,22 @@ class Scatterplot (Layer):
                 drawing.circle(x_coord, y_coord, 3)
                 drawing.fill('red', 0.2)
         drawing.restore()
-        
+
         # Restore context
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class InterpolationGraph (Layer):
     # TODO: Support graphing of tuple data
     """A graph of an interpolation curve, defined by a list of Keyframes and
-    an interpolation method."""
+    an interpolation method.
+    """
     def __init__(self, keyframes, size=(240, 80), method='linear'):
         """Create an interpolation graph of the given keyframes, at the given
-        size, using the given interpolation method."""
+        size, using the given interpolation method.
+        """
         Layer.__init__(self)
-                
+
         self.keyframes = keyframes
         self.size = size
         self.method = method
@@ -737,7 +715,7 @@ class InterpolationGraph (Layer):
             x = int(key.frame * x_scale)
             drawing.line(x, 0,   x, height)
             drawing.stroke('red')
-            
+
         # Draw Keyframe labels
         drawing.set_source('white')
         for key in self.keyframes:
@@ -759,13 +737,11 @@ class InterpolationGraph (Layer):
         drawing.restore()
 
 
-### --------------------------------------------------------------------
-
 class ColorBars (Layer):
     """Standard SMPTE color bars
     (http://en.wikipedia.org/wiki/SMPTE_color_bars)
     """
-    def __init__(self, size, position=(0,0)):
+    def __init__(self, size, position=(0, 0)):
         """Create color bars in a region of the given size and position.
         """
         Layer.__init__(self)
@@ -836,6 +812,7 @@ class ColorBars (Layer):
 
 
 
+
 if __name__ == '__main__':
     images = None
     # Get arguments, if any
@@ -845,7 +822,7 @@ if __name__ == '__main__':
 
     # A Drawing to render Layer demos to
     drawing = Drawing(800, 600)
-    
+
     # Draw a background layer
     bgd = Background(color='#7080A0')
     bgd.draw(drawing, 1)
@@ -916,6 +893,7 @@ if __name__ == '__main__':
     plot = Scatterplot(xy_data, 200, 200, "Spam", "Eggs")
     plot.draw(drawing, 1)
     drawing.restore()
-    
+
     log.info("Output to /tmp/my.png")
     save_image(drawing, '/tmp/my.png', 800, 600)
+
