@@ -1,17 +1,16 @@
-#! /usr/bin/env python
 # runtest.py
 
 """libtovid test script
 
 Execute this script to run tests on the modules in libtovid. These tests
 consist of executing each libtovid module standalone; it is presumed that
-each module to be tested contains at least the following:
+each module to be tested contains at least the following::
 
     import unittest
     if __name__ == '__main__':
         unittest.main()
 
-which runs unit tests, or:
+which runs unit tests, or::
 
     import doctest
     if __name__ == '__main__':
@@ -19,37 +18,47 @@ which runs unit tests, or:
 
 which does an automated verification of the docstrings in each module.
 
-NB -- You're going to get lots of output, so a >log.txt is advised.
+NB -- You're going to get lots of output, so a ``> log.txt`` is advised.
 """
 
 import os
 import commands
 from glob import glob
 
-# Unit test modules
-mod_test = glob('test/*.py')
-# Library modules
-# mod_libtovid = glob('*.py') ?
-mod_libtovid = [\
+libtovid_modules = [
+    'author.py',
     'cli.py',
     'deps.py',
-    'layout.py',
+    'encode.py',
     'media.py',
+    'odict.py',
     'opts.py',
     'standard.py',
     'stats.py',
-    'utils.py']
-mod_author = glob('author/*.py')
-mod_render = glob('render/*.py')
-mod_transcode = glob('transcode/*.py')
-modules = mod_test + mod_libtovid + mod_author + mod_render + mod_transcode
+    'xml.py',
+]
+
+subdirs = [
+    'backend',
+    'metagui',
+    'render',
+    'template',
+    'test',
+    'util',
+]
+
+subdir_modules = []
+for subdir in subdirs:
+    subdir_modules.extend(glob('%s/*.py' % subdir))
+
+all_modules = libtovid_modules + subdir_modules
 
 if __name__ == '__main__':
     # Execute each module
-    for mod in modules:
-        print "Testing: %s" % mod
+    for mod in all_modules:
+        print("Testing: %s" % mod)
         try:
-            print commands.getoutput('python %s' % mod)
+            print(commands.getoutput('python %s' % mod))
         except KeyboardInterrupt:
-            print "Test interrupted."
+            print("Test interrupted.")
             exit()
